@@ -1182,7 +1182,7 @@ static void init_config (void)
 
 #ifdef PLUGIN_NAME
 
-void init_plugin (void)
+void init_plugin (GtkWidget *parent)
 {
     setlocale (LC_ALL, "");
     bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -1208,6 +1208,7 @@ void init_plugin (void)
         wm_fn = openbox_functions;
     }
 
+    main_dlg = parent;
     builder = gtk_builder_new_from_file (PACKAGE_DATA_DIR "/ui/raindrop.ui");
 
     load_scale ();
